One-line entry point for launching the scanner.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
open(
BuildContext context, {PaperScannerOptions options = const PaperScannerOptions(), PaperScannerStyle style = const PaperScannerStyle(), bool fullscreenDialog = true}) → Future< PaperScanResult?> -
Pushes the PaperScannerScreen and resolves to the scan result, or
nullif the user cancelled.