PaperScannerLabels class
All user-facing strings, so consumers localize the scanner with their own translations. Defaults match the reference design.
Constructors
- PaperScannerLabels({String readyForNextScan = 'Bereit für den nächsten Scan.', String cropTitle = 'Ecken anpassen', String retake = 'Neu aufnehmen', String keep = 'Behalten', String done = 'Fertig', String cancel = 'Abbrechen', String review = 'Überprüfen', String delete = 'Löschen', String flash = 'Blitz', String filters = 'Filter', String autoShutter = 'Auslöser', String crop = 'Zuschneiden', String rotate = 'Drehen', String edit = 'Bearbeiten', String save = 'Speichern', String addPage = 'Hinzufügen', String auto = 'Auto', String manual = 'Manuell', String filterOriginal = 'Original', String filterEnhance = 'Verbessern', String filterGrayscale = 'Graustufen', String filterBlackWhite = 'S/W', String cameraPermissionTitle = 'Kamerazugriff erforderlich', String cameraPermissionMessage = 'Erlaube den Kamerazugriff, um Dokumente zu scannen.', String retryCamera = 'Erneut versuchen', String pageCounter = 'Seite', String processing = 'Wird verarbeitet...', String maxPagesReached = 'Maximale Seitenanzahl erreicht'})
-
const
Properties
- addPage → String
-
final
- auto → String
-
final
- autoShutter → String
-
final
- cameraPermissionMessage → String
-
final
- cameraPermissionTitle → String
-
final
- cancel → String
-
final
- crop → String
-
final
- cropTitle → String
-
final
- delete → String
-
final
- done → String
-
final
- edit → String
-
final
- filterBlackWhite → String
-
final
- filterEnhance → String
-
final
- filterGrayscale → String
-
final
- filterOriginal → String
-
final
- filters → String
-
final
- flash → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- keep → String
-
final
- manual → String
-
final
- maxPagesReached → String
-
final
- pageCounter → String
-
final
- processing → String
-
final
- readyForNextScan → String
-
final
- retake → String
-
final
- retryCamera → String
-
final
- review → String
-
final
- rotate → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- save → String
-
final
Methods
-
filterName(
ScanFilter filter) → String - The display label for a ScanFilter.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
Locale locale) → PaperScannerLabels -
Returns built-in labels for
locale, preserving any custom labels that differ from the German defaults. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited